@@ -10,11 +10,11 @@ HTML::ExtractMeta - Helper class for extracting useful meta data from HTML pages
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 =head1 SYNOPSIS
 
@@ -30,8 +30,8 @@ our $VERSION = '0.20';
     print "Type        = " . $em->type        . "\n";
     print "Locale      = " . $em->locale      . "\n";
     print "Image URL   = " . $em->image_url   . "\n";
-    print "Authors     = " . join( ', ', @{$em->get_authors} )  . "\n";
-    print "Keywords    = " . join( ', ', @{$em->get_keywords} ) . "\n";
+    print "Authors     = " . join( ', ', @{$em->authors} )  . "\n";
+    print "Keywords    = " . join( ', ', @{$em->keywords} ) . "\n";
 
 =head1 DESCRIPTION
 
